@@ -1,3 +1,4 @@
+# coding=utf-8
 from QuickStart_Rhy.API import *
 import qiniu
 
@@ -9,6 +10,8 @@ class Qiniu_oss_api:
         """
         初始化并登陆七牛云对象存储
 
+        Initializes and logs in qiniu cloud object storage
+
         :param ac_key: Access Key
         :param sc_key: Secret Key
         :param df_bucket: 默认桶名称
@@ -22,6 +25,8 @@ class Qiniu_oss_api:
         """
         获取对象支持的操作
 
+        Gets the operations supported by the object
+
         :return: 函数表
         """
         return {
@@ -36,6 +41,8 @@ class Qiniu_oss_api:
         """
         上传文件
 
+        Upload file
+
         :param filePath: 文件路径
         :param bucket: 桶名称，缺省使用self.df_bucket
         :return: None
@@ -47,6 +54,8 @@ class Qiniu_oss_api:
         """
         删除文件
 
+        Delete file
+
         :param filePath: 文件路径（对象存储中）
         :param bucket: 桶名称，缺省使用self.df_bucket
         :return: None
@@ -58,6 +67,8 @@ class Qiniu_oss_api:
         """
         通过url拷贝文件（这个接口貌似没有卵用，七牛云那边并不会生效）
 
+        Copy files through URL (this interface seems to have no egg use, qiniu cloud will not work)
+
         :param filePath: 文件链接
         :param bucket: 桶名称，缺省使用self.df_bucket
         :return: None
@@ -69,6 +80,8 @@ class Qiniu_oss_api:
         """
         获取当前桶的访问链接
 
+        Gets the access link for the current bucket
+
         :param bucket: 桶名称，缺省使用self.df_bucket
         :return: 成功返回json，否则False
         """
@@ -89,6 +102,8 @@ class Qiniu_oss_api:
         """
         展示bucket中所有的文件
 
+        Displays all the files in the bucket
+
         :param bucket: 桶名称，缺省使用self.df_bucket
         :return: None
         """
@@ -111,6 +126,8 @@ class Qiniu_oss_api:
         """
         下载文件
 
+        Download file
+
         :param filePath: 文件在桶中的路径
         :param bucket: 桶名称，缺省使用self.df_bucket
         :return: None
