@@ -1,3 +1,4 @@
+# coding=utf-8
 from PIL import Image
 
 
@@ -5,6 +6,8 @@ def transport_back(src: str, to_color, from_color=(0, 0, 0, 0)):
     """
     图片颜色替换
 
+    Image color replacement
+
     :param src: 图片路径
     :param to_color: RGBA四元组 -> 转换至目标颜色
     :param from_color: RGBA四元组 -> 需要被转换的颜色
@@ -30,6 +33,8 @@ def get_color_from_str(str_color: str):
     """
     解析字符串为RGBA四元组
 
+    Parse strings for RGBA quaternions
+
     :param str_color: 表示颜色的字符串（支持16进制、RGB或RGBA）
     :return: RGBA四元组
     """
