@@ -1,3 +1,4 @@
+# coding=utf-8
 from socketserver import ThreadingMixIn
 from http.server import SimpleHTTPRequestHandler
 from http.server import HTTPServer
@@ -11,6 +12,8 @@ class HttpServers:
         """
         http服务类初始化
 
+        HTTP service class initialization
+
         :param ip: 绑定的ip
         :param port: 端口
         :param url: 对外显示的访问url
@@ -27,6 +30,8 @@ class HttpServers:
         """
         开启http服务
 
+        Start the HTTP service
+
         :return: None
         """
         HttpServers.signal.signal(HttpServers.signal.SIGINT, self.shutdown)
@@ -51,3 +56,5 @@ class HttpServers:
         self.httpd.server_close()
         print('HTTP Server: Closed.')
         exit(0)
+
+
