@@ -1,3 +1,4 @@
+# coding=utf-8
 from QuickStart_Rhy import dir_char, system
 
 miss_file = ['.DS_Store']
@@ -7,6 +8,8 @@ def top():
     """
     CPU和内存监测
 
+    CPU and memory monitoring
+
     :return: None
     """
     import time
@@ -57,6 +60,8 @@ def clear_mem():
     """
     清理系统内存
 
+    Clean system memory
+
     :return: None
     """
     if dir_char == '\\':
@@ -74,6 +79,8 @@ def mktar():
     """
     创建tar包
 
+    Create a tar packages
+
     :return: None
     """
     import os
@@ -99,6 +106,8 @@ def untar():
     """
     解压tar包
 
+    Unpack the tar packages
+
     :return: None
     """
     import os
@@ -133,6 +142,8 @@ def mkzip():
     """
     创建ZIP包
 
+    Create a ZIP package
+
     :return: None
     """
     import os
@@ -158,6 +169,8 @@ def unzip():
     """
     解压ZIP包
 
+    Unpack the ZIP package
+
     :return: None
     """
     import os
@@ -192,6 +205,8 @@ def unrar():
     """
     解压RAR包
 
+    Extract RAR package
+
     :return: None
     """
     import os
